unit ODTHandlerMain;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls,
  fpvectorialpkg, fpvectorial, fileutil, zipper, strutils;

type

  { TfrmODTHandler }

  TfrmODTHandler = class(TForm)
    btnMakeODTFile: TButton;
    edText: TEdit;
    procedure btnMakeODTFileClick(Sender: TObject);
  private

  public

  end;

var
  frmODTHandler: TfrmODTHandler;

implementation

{$R *.lfm}

{ TfrmODTHandler }

procedure TfrmODTHandler.btnMakeODTFileClick(Sender: TObject);
var
  Document : TvVectorialDocument;
  Page : TvTextPageSequence;
  Paragraph : TvParagraph;
  BoldTextStyle : TvStyle;
  ItalicTextStyle : TvStyle;
  StrikeThroughTextStyle : TvStyle;
  UnderlineTextStyle : TvStyle;
  textStyle : TvStyle;
  redStyle : TvStyle;
  greenStyle : TvStyle;
  blueStyle : TvStyle;
  UnZipper : TUnZipper;
  temp : string;
  tempList : TStringList;
  n : integer;
begin
  // delete possible old test files and directory
  if FileExists('ODT-test.odt') then
    DeleteFile('ODT-test.odt');
  if FileExists('ODT-test.zip') then
    DeleteFile('ODT-test.zip');
  if DirectoryExists('ODT-test') then
    DeleteDirectory('ODT-test', false);

  tempList := TStringList.Create;
  try
    tempList.Text := AnsiReplaceText(edText.Text, ' ', lineEnding);
    Document := TvVectorialDocument.Create;
    try
      //  Adds the defaut Paragraph Styles
      //    StyleTextBody, StyleHeading1,
      //    StyleHeading2 & StyleHeading3
      Document.AddStandardTextDocumentStyles(vfUnknown);

      // Add our own Style
      BoldTextStyle := Document.AddStyle();
      BoldTextStyle.Kind := vskTextSpan;
      BoldTextStyle.Name := 'BoldText';
      BoldTextStyle.Font.Bold := true;
      BoldTextStyle.Font.Color := TColorToFPColor(clRed);
      BoldTextStyle.SetElements := BoldTextStyle.SetElements +  [spbfFontBold];

      ItalicTextStyle := Document.AddStyle();
      ItalicTextStyle.Kind := vskTextSpan;
      ItalicTextStyle.Name := 'ItalicText';
      ItalicTextStyle.Font.Italic := true;
      ItalicTextStyle.Font.Color := TColorToFPColor(clRed);
      ItalicTextStyle.SetElements := BoldTextStyle.SetElements +
        [spbfFontItalic];

      StrikeThroughTextStyle := Document.AddStyle();
      StrikeThroughTextStyle.Kind := vskTextSpan;
      StrikeThroughTextStyle.Name := 'StrikeThroughText';
      StrikeThroughTextStyle.Font.StrikeThrough := true;
      StrikeThroughTextStyle.SetElements := StrikeThroughTextStyle.SetElements +
        [spbfFontStrikeThrough];

      UnderlineTextStyle := Document.AddStyle();
      UnderlineTextStyle.Kind := vskTextSpan;
      UnderlineTextStyle.Name := 'UnderLineText';
      UnderlineTextStyle.Font.Underline := true;
      UnderlineTextStyle.SetElements := StrikeThroughTextStyle.SetElements +
        [spbfFontUnderline];

      redStyle := Document.AddStyle();
      redStyle.Kind := vskTextSpan;
      redStyle.Name := 'RedText';
      redStyle.Font.Color := TColorToFPColor(clRed);
      redStyle.SetElements := StrikeThroughTextStyle.SetElements +
        [spbfFontColor];

      greenStyle := Document.AddStyle();
      greenStyle.Kind := vskTextSpan;
      greenStyle.Name := 'GreenText';
      greenStyle.Font.Color := TColorToFPColor(clGreen);
      greenStyle.SetElements := StrikeThroughTextStyle.SetElements +
        [spbfFontColor];

      blueStyle := Document.AddStyle();
      blueStyle.Kind := vskTextSpan;
      blueStyle.Name := 'BlueText';
      blueStyle.Font.Color := TColorToFPColor(clBlue);
      blueStyle.SetElements := StrikeThroughTextStyle.SetElements +
        [spbfFontColor];

      Page := Document.AddTextPageSequence;
      Paragraph := Page.AddParagraph;
      n := 0;
      while n < tempList.Count do
      begin
        case n of
          0: textStyle := BoldTextStyle;
          1: textStyle := ItalicTextStyle;
          2: textStyle := StrikeThroughTextStyle;
          3: textStyle := UnderlineTextStyle;
          4: textStyle := redStyle;
          5: textStyle := greenStyle;
          6: textStyle := blueStyle;
        end;

        Paragraph.AddText(tempList.Strings[n] + ' ').Style := textStyle;

        Inc(n);
      end;
{      Paragraph.AddText('Hello ').Style := StrikeThroughTextStyle;
      Paragraph.AddText('world').Style := BoldTextStyle;}

      Document.WriteToFile('ODT-test.odt', vfODT);

      // create a zip-file copy of odt-file
      CopyFile('ODT-test.odt', 'ODT-test.zip');

      // unzip the zip-file to make it possible to investigate the files
      // contained within the odt-file
      UnZipper := TUnZipper.Create;
      try
        UnZipper.FileName := 'ODT-test.zip';
        UnZipper.OutputPath := 'ODT-test';
        UnZipper.Examine;
        UnZipper.UnZipAllFiles;
      finally
        UnZipper.Free;
      end;
    finally
      Document.Free;
    end;
  finally
    FreeAndNil(tempList);

    ShowMessage('Done');
  end;
end;

end.

